<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://saschapaukner.de
 * @since      1.0.0
 *
 * @package    Responsive_Block_Control
 * @subpackage Responsive_Block_Control/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Responsive_Block_Control
 * @subpackage Responsive_Block_Control/public
 * @author     landwire <mail@saschapaukner.de>
 */
class Responsive_Block_Control_Public {

    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string $plugin_name The ID of this plugin.
     */
    private $plugin_name;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string $version The current version of this plugin.
     */
    private $version;

    /**
     * Initialize the class and set its properties.
     *
     * @param string $plugin_name The name of the plugin.
     * @param string $version The version of this plugin.
     *
     * @since    1.0.0
     */
    public function __construct($plugin_name, $version) {

        $this->plugin_name = $plugin_name;
        $this->version = $version;

    }

    /**
     * Register the stylesheets for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function enqueue_styles() {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Responsive_Block_Control_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Responsive_Block_Control_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */

        wp_enqueue_style($this->plugin_name, plugin_dir_url(__FILE__) . 'css/responsive-block-control-public.css', [], $this->version, 'all');

    }

    /**
     * Register the JavaScript for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function enqueue_scripts() {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Responsive_Block_Control_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Responsive_Block_Control_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */

        wp_enqueue_script($this->plugin_name, plugin_dir_url(__FILE__) . 'js/responsive-block-control-public.js', ['jquery'], $this->version, FALSE);

        $options = get_option('responsiveBlockControl');
        $new_options['breakPoints'] = apply_filters('responsive_block_control_breakpoints', $options['breakPoints']);
        $new_options['addCssToHead'] = apply_filters('responsive_block_control_addcss', $options['addCssToHead']);
        $options = array_replace_recursive($options, $new_options);

        wp_localize_script($this->plugin_name, 'responsiveBlockControlOptions', $options);

    }

}
