<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://saschapaukner.de
 * @since             1.0.0
 * @package           Responsive_Block_Control
 *
 * @wordpress-plugin
 * Plugin Name:       Responsive Block Control
 * Description:       Responsive Block Control adds responsive toggles to a "Visibility" panel of the block editor to show or hide blocks according to screen width.
 * Version:           1.0.0
 * Author:            Sascha Paukner
 * Author URI:        https://saschapaukner.de
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       responsive-block-control
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'RESPONSIVE_BLOCK_CONTROL_VERSION', '1.0.0' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-responsive-block-control-activator.php
 */
function activate_responsive_block_control() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-responsive-block-control-activator.php';
	Responsive_Block_Control_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-responsive-block-control-deactivator.php
 */
function deactivate_responsive_block_control() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-responsive-block-control-deactivator.php';
	Responsive_Block_Control_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_responsive_block_control' );
register_deactivation_hook( __FILE__, 'deactivate_responsive_block_control' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-responsive-block-control.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_responsive_block_control() {

	$plugin = new Responsive_Block_Control();
	$plugin->run();

}
run_responsive_block_control();
